@@ -29,7 +29,7 @@ class UniUtil:
         res = False
         try:
             requests.packages.urllib3.disable_warnings()
-            rep = requests.get(url, verify=False)
+            rep = requests.get(url, verify=False, timeout=10)
             if rep.status_code != 400:
                 res = True
         except Exception as e:
